Re: [PATCH] D12265: [ZORG] Add support for libc++ to SphinxDocBuilder.py

2015-08-24 Thread Eric Fiselier via cfe-commits
EricWF accepted this revision.
EricWF added a reviewer: EricWF.
EricWF added a comment.
This revision is now accepted and ready to land.

Accepting so I can commit.



Comment at: buildbot/osuosl/master/config/builders.py:1166
@@ +1165,3 @@
+   'name':libcxx-sphinx-docs,
+   'slavenames':[ericwf-buildslave2],
+   'builddir':libcxx-sphinx-docs,

delcypher wrote:
 Is there a reason you're using the slave `ericwf-buildslave2` rather than 
 `gribozavr4` which is used by the other documentation builders?
 
 
I have my own hardware that I might as well use. I wanted to keep gribozavr's 
hardware as free as possible in case other people need it.


Comment at: buildbot/osuosl/master/config/builders.py:1341
@@ -1333,3 +1340,3 @@
  'factory' : LNTBuilder.getLNTFactory(triple='x86_64-apple-darwin10',
-  nt_flags=['--multisample=3', 
+  nt_flags=['--multisample=3',
 '--optimize-option',

delcypher wrote:
 This spacing change doesn't really belong in this patch
I know :-( but for some reason my editor refused to leave it out. 


http://reviews.llvm.org/D12265



___
cfe-commits mailing list
cfe-commits@lists.llvm.org
http://lists.llvm.org/cgi-bin/mailman/listinfo/cfe-commits


Re: [PATCH] D12265: [ZORG] Add support for libc++ to SphinxDocBuilder.py

2015-08-24 Thread Eric Fiselier via cfe-commits
EricWF updated this revision to Diff 33029.
EricWF marked 2 inline comments as done.

http://reviews.llvm.org/D12265

Files:
  buildbot/osuosl/master/config/builders.py
  zorg/buildbot/builders/SphinxDocsBuilder.py

Index: buildbot/osuosl/master/config/builders.py
===
--- buildbot/osuosl/master/config/builders.py
+++ buildbot/osuosl/master/config/builders.py
@@ -1161,6 +1161,13 @@
'factory': 
SphinxDocsBuilder.getSphinxDocsBuildFactory(lld_html=True),
'category' : 'lld'
  },
+ {
+   'name':libcxx-sphinx-docs,
+   'slavenames':[ericwf-buildslave2],
+   'builddir':libcxx-sphinx-docs,
+   'factory': 
SphinxDocsBuilder.getSphinxDocsBuildFactory(libcxx_html=True),
+   'category' : 'libcxx'
+ }
]
 
 def get_builders():


Index: zorg/buildbot/builders/SphinxDocsBuilder.py
===
--- zorg/buildbot/builders/SphinxDocsBuilder.py
+++ zorg/buildbot/builders/SphinxDocsBuilder.py
@@ -6,10 +6,11 @@
 from zorg.buildbot.commands.NinjaCommand import NinjaCommand
 
 def getSphinxDocsBuildFactory(
-llvm_html  = False, # Build LLVM HTML documentation
-llvm_man   = False, # Build LLVM man pages
-clang_html = False, # Build Clang HTML documentation
-lld_html   = False  # Build LLD HTML documentation
+llvm_html   = False, # Build LLVM HTML documentation
+llvm_man= False, # Build LLVM man pages
+clang_html  = False, # Build Clang HTML documentation
+lld_html= False, # Build LLD HTML documentation
+libcxx_html = False  # Build Libc++ HTML documentation
 ):
 
 f = buildbot.process.factory.BuildFactory()
@@ -18,6 +19,8 @@
 llvm_objdir = 'llvm/build'
 clang_srcdir = llvm_srcdir + '/tools/clang'
 lld_srcdir = llvm_srcdir + '/tools/lld'
+libcxx_srcdir = llvm_srcdir + '/projects/libcxx'
+libcxxabi_srcdir = llvm_srcdir + '/projects/libcxxabi'
 
 # Get LLVM. This is essential for all builds
 # because we build all subprojects in tree
@@ -41,6 +44,18 @@
   defaultBranch='trunk',
   workdir=lld_srcdir))
 
+if 

[PATCH] D12265: [ZORG] Add support for libc++ to SphinxDocBuilder.py

2015-08-22 Thread Eric Fiselier via cfe-commits
EricWF created this revision.
EricWF added reviewers: delcypher, silvas.
EricWF added subscribers: llvm-commits, cfe-commits.

http://reviews.llvm.org/D12265

Files:
  buildbot/osuosl/master/config/builders.py
  zorg/buildbot/builders/SphinxDocsBuilder.py

Index: buildbot/osuosl/master/config/builders.py
===
--- buildbot/osuosl/master/config/builders.py
+++ buildbot/osuosl/master/config/builders.py
@@ -1161,6 +1161,13 @@
'factory': 
SphinxDocsBuilder.getSphinxDocsBuildFactory(lld_html=True),
'category' : 'lld'
  },
+ {
+   'name':libcxx-sphinx-docs,
+   'slavenames':[ericwf-buildslave2],
+   'builddir':libcxx-sphinx-docs,
+   'factory': 
SphinxDocsBuilder.getSphinxDocsBuildFactory(libcxx_html=True),
+   'category' : 'libcxx'
+ }
]
 
 def get_builders():
@@ -1331,7 +1338,7 @@
  'slavenames' :[lab-mini-03],
  'builddir' :clang-x86_64-darwin10-nt-O0-g,
  'factory' : LNTBuilder.getLNTFactory(triple='x86_64-apple-darwin10',
-  nt_flags=['--multisample=3', 
+  nt_flags=['--multisample=3',
 '--optimize-option',
 '-O0', '--cflag', '-g'],
   jobs=2,  use_pty_in_tests=True,


Index: zorg/buildbot/builders/SphinxDocsBuilder.py
===
--- zorg/buildbot/builders/SphinxDocsBuilder.py
+++ zorg/buildbot/builders/SphinxDocsBuilder.py
@@ -6,10 +6,11 @@
 from zorg.buildbot.commands.NinjaCommand import NinjaCommand
 
 def getSphinxDocsBuildFactory(
-llvm_html  = False, # Build LLVM HTML documentation
-llvm_man   = False, # Build LLVM man pages
-clang_html = False, # Build Clang HTML documentation
-lld_html   = False  # Build LLD HTML documentation
+llvm_html   = False, # Build LLVM HTML documentation
+llvm_man= False, # Build LLVM man pages
+clang_html  = False, # Build Clang HTML documentation
+lld_html= False, # Build LLD HTML documentation
+libcxx_html = False # Build Libc++ HTML 

Re: [PATCH] D12265: [ZORG] Add support for libc++ to SphinxDocBuilder.py

2015-08-22 Thread Dan Liew via cfe-commits
delcypher added a comment.

The rest LGTM



Comment at: buildbot/osuosl/master/config/builders.py:1166
@@ +1165,3 @@
+   'name':libcxx-sphinx-docs,
+   'slavenames':[ericwf-buildslave2],
+   'builddir':libcxx-sphinx-docs,

Is there a reason you're using the slave `ericwf-buildslave2` rather than 
`gribozavr4` which is used by the other documentation builders?




Comment at: buildbot/osuosl/master/config/builders.py:1341
@@ -1333,3 +1340,3 @@
  'factory' : LNTBuilder.getLNTFactory(triple='x86_64-apple-darwin10',
-  nt_flags=['--multisample=3', 
+  nt_flags=['--multisample=3',
 '--optimize-option',

This spacing change doesn't really belong in this patch


Comment at: zorg/buildbot/builders/SphinxDocsBuilder.py:13
@@ -13,1 +12,3 @@
+lld_html= False, # Build LLD HTML documentation
+libcxx_html = False # Build Libc++ HTML documentation
 ):

Minor nit, the ``#`` should probably be horizontally aligned with the others


http://reviews.llvm.org/D12265



___
cfe-commits mailing list
cfe-commits@lists.llvm.org
http://lists.llvm.org/cgi-bin/mailman/listinfo/cfe-commits
Index: zorg/buildbot/builders/SphinxDocsBuilder.py
===
--- zorg/buildbot/builders/SphinxDocsBuilder.py
+++ zorg/buildbot/builders/SphinxDocsBuilder.py
@@ -6,10 +6,11 @@
 from zorg.buildbot.commands.NinjaCommand import NinjaCommand
 
 def getSphinxDocsBuildFactory(
-llvm_html  = False, # Build LLVM HTML documentation
-llvm_man   = False, # Build LLVM man pages
-clang_html = False, # Build Clang HTML documentation
-lld_html   = False  # Build LLD HTML documentation
+llvm_html   = False, # Build LLVM HTML documentation
+llvm_man= False, # Build LLVM man pages
+clang_html  = False, # Build Clang HTML documentation
+lld_html= False, # Build LLD HTML documentation
+libcxx_html = False  # Build Libc++ HTML documentation
 ):
 
 f = buildbot.process.factory.BuildFactory()
@@ -18,6 +19,8 @@
 llvm_objdir = 'llvm/build'
 clang_srcdir = llvm_srcdir + '/tools/clang'
 lld_srcdir = llvm_srcdir + '/tools/lld'
+libcxx_srcdir = llvm_srcdir + '/projects/libcxx'
+libcxxabi_srcdir = llvm_srcdir + '/projects/libcxxabi'
 
 # Get LLVM. This is essential for all builds
 # because we build all subprojects in tree
@@ -41,6 +44,18 @@
   defaultBranch='trunk',
   workdir=lld_srcdir))
 
+if libcxx_html:
+f.addStep(SVN(name='svn-libcxx',
+  mode='update',
+  baseURL='http://llvm.org/svn/llvm-project/libcxx/',
+  defaultBranch='trunk',
+  workdir=libcxx_srcdir))
+f.addStep(SVN(name='svn-libcxxabi',
+  mode='update',
+  baseURL='http://llvm.org/svn/llvm-project/libcxxabi/',
+  defaultBranch='trunk',
+  workdir=libcxxabi_srcdir))
+
 f.addStep(ShellCommand(name=create-build-dir,
command=[mkdir, -p, llvm_objdir],
haltOnFailure=False, # We might of already 
created the directory in a previous build
@@ -92,4 +107,12 @@
targets=['docs-lld-html']
   ))
 
+if libcxx_html:
+f.addStep(NinjaCommand(name=docs-libcxx-html,
+   haltOnFailure=True,
+   description=[Build Libc++ Sphinx HTML 
documentation],
+   workdir=llvm_objdir,
+   targets=['docs-libcxx-html']
+  ))
+
 return f
Index: zorg/buildbot/builders/SphinxDocsBuilder.py
===
--- zorg/buildbot/builders/SphinxDocsBuilder.py
+++ zorg/buildbot/builders/SphinxDocsBuilder.py
@@ -6,10 +6,11 @@
 from zorg.buildbot.commands.NinjaCommand import NinjaCommand
 
 def getSphinxDocsBuildFactory(
-llvm_html  = False, # Build LLVM HTML documentation
-llvm_man   = False, # Build LLVM man pages
-clang_html = False, # Build Clang HTML documentation
-lld_html   = False  # Build LLD HTML documentation
+llvm_html   = False, # Build LLVM HTML documentation
+llvm_man= False, # Build LLVM man pages
+clang_html  = False, # Build Clang HTML documentation
+lld_html= False, # Build LLD HTML documentation
+libcxx_html = False # Build Libc++ HTML documentation
 ):
 
 f = buildbot.process.factory.BuildFactory()
@@ -18,6 +19,8 @@
 llvm_objdir = 'llvm/build'
 clang_srcdir = llvm_srcdir + '/tools/clang'
 lld_srcdir = llvm_srcdir + '/tools/lld'
+libcxx_srcdir = llvm_srcdir + '/projects/libcxx'
+libcxxabi_srcdir = llvm_srcdir + '/projects/libcxxabi'
 
 # Get LLVM. This is essential for all builds
 # because we build all subprojects in tree
@@ -41,6 +44,18 @@
   defaultBranch='trunk',
   workdir=lld_srcdir))
 
+if libcxx_html:
+f.addStep(SVN(name='svn-libcxx',
+  mode='update',
+  baseURL='http://llvm.org/svn/llvm-project/libcxx/',
+  defaultBranch='trunk',
+  workdir=libcxx_srcdir))
+f.addStep(SVN(name='svn-libcxxabi',
+  mode='update',
+  baseURL='http://llvm.org/svn/llvm-project/libcxxabi/',
+  defaultBranch='trunk',
+  workdir=libcxxabi_srcdir))
+
 f.addStep(ShellCommand(name=create-build-dir,
command=[mkdir, -p, llvm_objdir],
haltOnFailure=False, # We might of already 
created the directory in a previous build
@@ -92,4 +107,12 @@
targets=['docs-lld-html']
   ))
 
+if libcxx_html:
+f.addStep(NinjaCommand(name=docs-libcxx-html,
+   haltOnFailure=True,
+   description=[Build Libc++ Sphinx HTML 
documentation],
+   workdir=llvm_objdir,
+   targets=['docs-libcxx-html']
+  ))
+
 return f